aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorAndrey Ponomarenko <andrewponomarenko@yandex.ru>2016-05-14 17:55:06 +0300
committerAndrey Ponomarenko <andrewponomarenko@yandex.ru>2016-05-14 17:55:06 +0300
commitb3118d9752afef5233235b4f95359357b2e72432 (patch)
treefbb4e365172621e378eba38b995854fbe86aab32
parent512878d58f5ff85a0ce2db0dee2c108ed5e24fb4 (diff)
downloadabi-compliance-checker-b3118d9752afef5233235b4f95359357b2e72432.tar.gz
Use regular expressions instead of wildcards in -skip-* options.
-rw-r--r--INSTALL4
-rw-r--r--abi-compliance-checker.pl20
-rw-r--r--doc/Changelog.html9
3 files changed, 18 insertions, 15 deletions
diff --git a/INSTALL b/INSTALL
index 6d9bd04..81f473f 100644
--- a/INSTALL
+++ b/INSTALL
@@ -9,8 +9,8 @@ All rights reserved.
RELEASE INFORMATION
Project: ABI Compliance Checker (ABICC)
-Version: 1.99.19
-Date: 2016-04-18
+Version: 1.99.20
+Date: 2016-05-14
This file explains how to install and setup environment
diff --git a/doc/Changelog.html b/doc/Changelog.html
index 9c0678d..7cb1649 100644
--- a/doc/Changelog.html
+++ b/doc/Changelog.html
@@ -44,6 +44,15 @@
<p/>
<br/>
+<b>Version 1.99.20 (May 14, 2016)</b><br/>
+<b>Improvements</b>
+<ul>
+ <li>
+ Use regular expressions instead of wildcards in -skip-* options
+ </li>
+</ul>
+<br/>
+
<b>Version 1.99.19 (April 18, 2016)</b><br/>
<b>Improvements</b>
<ul>
diff --git a/abi-compliance-checker.pl b/abi-compliance-checker.pl
index 9cfbb24..4ea32b9 100644
--- a/abi-compliance-checker.pl
+++ b/abi-compliance-checker.pl
@@ -1,6 +1,6 @@
#!/usr/bin/perl
###########################################################################
# ABI Compliance Checker (ABICC) 1.99.19
# A tool for checking backward compatibility of a C/C++ library API
#
# Copyright (C) 2009-2011 Institute for System Programming, RAS
@@ -60,7 +60,7 @@ use Storable qw(dclone);
use Data::Dumper;
use Config;
-my $TOOL_VERSION = "1.99.19";
+my $TOOL_VERSION = "1.99.20";
my $ABI_DUMP_VERSION = "3.2";
my $XML_REPORT_VERSION = "1.2";
my $XML_ABI_DUMP_VERSION = "1.2";
@@ -1762,9 +1762,8 @@ sub get_CmdPath_Default_I($)
sub classifyPath($)
{
my $Path = $_[0];
- if($Path=~/[\*\[]/)
- { # wildcard
- $Path=~s/\*/.*/g;
+ if($Path=~/[\*\+\(\[\|]/)
+ { # pattern
$Path=~s/\\/\\\\/g;
return ($Path, "Pattern");
}
@@ -1932,6 +1931,7 @@ sub readDescriptor($$)
foreach my $Path (split(/\s*\n\s*/, $Descriptor{$LibVersion}{"SkipHeaders"}))
{
$SkipHeadersList{$LibVersion}{$Path} = 1;
+
my ($CPath, $Type) = classifyPath($Path);
$SkipHeaders{$LibVersion}{$Type}{$CPath} = 1;
}
@@ -20313,6 +20313,7 @@ sub read_ABI_Dump($$)
foreach my $Path (keys(%{$ABI->{"SkipHeaders"}}))
{
$SkipHeadersList{$LibVersion}{$Path} = $ABI->{"SkipHeaders"}{$Path};
+
my ($CPath, $Type) = classifyPath($Path);
$SkipHeaders{$LibVersion}{$Type}{$CPath} = $ABI->{"SkipHeaders"}{$Path};
}
@@ -22653,14 +22654,6 @@ sub scenario()
}
}
- if($SkipInternalSymbols) {
- $SkipInternalSymbols=~s/\*/.*/g;
- }
-
- if($SkipInternalTypes) {
- $SkipInternalTypes=~s/\*/.*/g;
- }
-
if($Quick) {
$ADD_TMPL_INSTANCES = 0;
}
@@ -22966,6 +22959,7 @@ sub scenario()
{ # register for both versions
$SkipHeadersList{1}{$Path} = 1;
$SkipHeadersList{2}{$Path} = 1;
+
my ($CPath, $Type) = classifyPath($Path);
$SkipHeaders{1}{$Type}{$CPath} = 1;
$SkipHeaders{2}{$Type}{$CPath} = 1;
@@ -1,6 +1,6 @@
#!/usr/bin/perl
###########################################################################
-# ABI Compliance Checker (ABICC) 1.99.19
+# ABI Compliance Checker (ABICC) 1.99.20
# A tool for checking backward compatibility of a C/C++ library API
#